==> free-sa-1.2.1.tar.gz: free-sa-1.2.1/src/reports/r_topsites.c <==
#include "global.h"


FILE *tTS1;


void ReportTopSites(void) {
    FILE *TSR, *tTS2;
    char turl[MAXLEN], oturl[MAXLEN], tname[MAXUSERNAME], tfname[MAXFILENAME];
    char *iname;
    double tBytes, urlBytes = 0;
    int tCount, urlNumber = 0;
    short int tIndic, urlIndic = 0;
    int i;

    SAfclose(tTS1, icfg.TSRname);

    /* sort by URL and internal name, i don't know why it's faster than sorting by url only */
    sprintf(turl, "%s/%s.uns", cfg.TempDir, icfg.TSRname);
    sprintf(tfname, "%s/%s", cfg.TempDir, icfg.TSRname);
    SAsystem(CMDSORT, CMDSORT, "-k", "1,2", "-o", tfname, turl, NULL);
    SAunlink(turl);

    oturl[0] = '\0';
    iname = (char *)SAmalloc((size_t)(icfg.ueCount * MAXUSERDESC));
	
    tTS1 = SAfopenI("r", tfname);
    tTS2 = SAfopenI("w", turl);

    while (fscanf(tTS1, "%s %s %d %lf %hd\n", turl, tname, &tCount, &tBytes, &tIndic) == 5) {
        if (strcmp(oturl, turl)) {
    	    if (oturl[0] != '\0') fprintf(tTS2, "%s %d %.0f %hd %s\n", oturl, urlNumber, urlBytes, urlIndic, iname);
		    
	    strcpy(oturl, turl);
	    strcpy(iname, tname);
	    urlNumber = tCount;
	    urlIndic = tIndic;
	    urlBytes = tBytes;
	} else {
	    /* fix for incorrect for us sorting, ex: http://m.ru & http://www.m.ru.net */
	    if (strcmp(iname, tname)) sprintf(&iname[strlen(iname)], ", %s", tname);
	    urlNumber += tCount;
	    urlIndic |= tIndic;
	    urlBytes += tBytes;
	}
    }
    
    /* write last data (because we use postwriting, not prewriting) */
    fprintf(tTS2, "%s %d %.0f %hd %s\n", oturl, urlNumber, urlBytes, urlIndic, iname);

    SAfcloseU(tTS1, tfname);
    SAfclose(tTS2, icfg.TSRname);

    /* sort by bytes (or required field) */
    sprintf(turl, "%s/%s.uns", cfg.TempDir, icfg.TSRname);
    sprintf(tfname, "%s/%s", cfg.TempDir, icfg.TSRname);
    SAsystem(CMDSORT, CMDSORT, "-k", "3,3nr", "-o", tfname, turl, NULL);
    SAunlink(turl);

    i = 1;
    tTS1 = SAfopenI("r", tfname);
    sprintf(turl, "%s (%s)", loc->Bytes, loc->Desc);
    TSR = SAfopenH("../", 'r', loc->TopSites, turl, 1, "w", "%s/%s.html", icfg.ReportDir, icfg.TSRname);
    fprintf(TSR, "<tr><th>%s<th>%s<th>%s<th>%s<th>%s\n", 
	    loc->No, loc->URL, loc->Connections, loc->Bytes, loc->Users);
    while(fscanf(tTS1, "%s %d %lf %hd %[^\n]", turl, &tCount, &tBytes, &tIndic, iname) == 5) {
	fprintf(TSR, "<tr><td>%d<td class=lt><a href=\"%s\">%s</a><td>%d<td>%'.0f<td class=lt>%s", 
		i++, turl, turl, tCount, tBytes, iname);
	Indics(TSR, tIndic);
    }
    SAfcloseH(TSR, icfg.TSRname);
    SAfcloseU(tTS1, tfname);
	
    /*TSUR = SAfopenH("../", "", "(no sort)", "w", "%s/g_%s.html", icfg.ReportDir, Users[i].name);*/
    /*qsort(Users, icfg.ueCount, sizeof(struct SAentry), (int (*)(const void *, const void *))compSAentry);*/
}

==> free-sa-1.2.4.tar.gz: free-sa-1.2.4/src/reports/r_topsites.c <==
#include "global.h"


FILE *tTS1;


void ReportTopSites(void) {
    FILE *TSR, *tTS2;
    char turl[MAXLEN], oturl[MAXLEN], tname[MAXUSERNAME], tfname[MAXFILENAME];
    char *iname;
    double tBytes, urlBytes = 0;
    int tCount, urlNumber = 0;
    short int tIndic, urlIndic = 0;
    int i;

    SAfclose(tTS1, icfg.TSRname);

    /* sort by URL and internal name, i don't know why it's faster than sorting by url only */
    snprintf(turl, sizeof(turl), "%s/%s.uns", cfg.TmpDir, icfg.TSRname);
    snprintf(tfname, sizeof(tfname), "%s/%s", cfg.TmpDir, icfg.TSRname);
    SAsystem(CMDSORT, CMDSORT, "-k", "1,2", "-o", tfname, turl, NULL);
    SAunlink(turl);

    oturl[0] = '\0';
    iname = (char *)SAmalloc((size_t)(icfg.ueCount * MAXUSERDESC));
	
    tTS1 = SAfopenI("r", tfname);
    tTS2 = SAfopenI("w", turl);

    while (fscanf(tTS1, "%s %s %d %lf %hd\n", turl, tname, &tCount, &tBytes, &tIndic) == 5) {
        if (strcmp(oturl, turl)) {
    	    if (oturl[0] != '\0') fprintf(tTS2, "%s %d %.0f %hd %s\n", oturl, urlNumber, urlBytes, urlIndic, iname);
		    
	    strcpy(oturl, turl);
	    strcpy(iname, tname);
	    urlNumber = tCount;
	    urlIndic = tIndic;
	    urlBytes = tBytes;
	} else {
	    /* fix for incorrect for us sorting, ex: http://m.ru & http://www.m.ru.net */
	    if (strcmp(iname, tname)) snprintf(&iname[strlen(iname)], sizeof(MAXUSERDESC) + 2, ", %s", tname);
	    urlNumber += tCount;
	    urlIndic |= tIndic;
	    urlBytes += tBytes;
	}
    }
    
    /* write last data (because we use postwriting, not prewriting) */
    fprintf(tTS2, "%s %d %.0f %hd %s\n", oturl, urlNumber, urlBytes, urlIndic, iname);

    SAfcloseU(tTS1, tfname);
    SAfclose(tTS2, icfg.TSRname);

    /* sort by bytes (or required field) */
    snprintf(turl, sizeof(turl), "%s/%s.uns", cfg.TmpDir, icfg.TSRname);
    snprintf(tfname, sizeof(tfname), "%s/%s", cfg.TmpDir, icfg.TSRname);
    SAsystem(CMDSORT, CMDSORT, "-k", "3,3nr", "-o", tfname, turl, NULL);
    SAunlink(turl);

    i = 1;
    tTS1 = SAfopenI("r", tfname);
    snprintf(turl, sizeof(turl), "%s (%s)", loc->Bytes, loc->Desc);
    TSR = SAfopenH("../", 'r', loc->TopSites, turl, 1, "w", "%s/%s.html", icfg.ReportDir, icfg.TSRname);
    fprintf(TSR, "<tr><th>%s<th>%s<th>%s<th>%s<th>%s\n", 
	    loc->No, loc->URL, loc->Connections, loc->Bytes, loc->Users);
    while(fscanf(tTS1, "%s %d %lf %hd %[^\n]", turl, &tCount, &tBytes, &tIndic, iname) == 5) {
	fprintf(TSR, "<tr><td>%d<td class=lt><a href=\"%s\">%s</a><td>%d<td>%'.0f<td class=lt>%s", 
		i++, turl, turl, tCount, tBytes, iname);
	Indics(TSR, tIndic);
    }
    SAfcloseH(TSR, icfg.TSRname);
    SAfcloseU(tTS1, tfname);
	
    /*TSUR = SAfopenH("../", "", "(no sort)", "w", "%s/g_%s.html", icfg.ReportDir, Users[i].name);*/
    /*qsort(Users, icfg.ueCount, sizeof(struct SAentry), (int (*)(const void *, const void *))compSAentry);*/
}
